package jpatest

import _root_.javax.persistence._
import org.scalatest.Suite

class Runner extends Suite {

  def testJPA_1 {
    val emf = Persistence createEntityManagerFactory "TestUnit"
    var id = -1
    {
      val em = emf.createEntityManager
      val p = new Project("Foo")
      val tx = em.getTransaction()
      try {
	tx.begin()
	em persist p
	tx.commit()
	id = p.id
      } catch {
	case e =>
	  tx.rollback();
        throw e
      }
      em.close()
    }
    {
      implicit val em = emf.createEntityManager
      val p2 = Project.find(id)
      try {
	assert("Foo" === p2.title)
      } finally {
	em.close()
      }
    }
  }

  def testJPA_2 {
    val emf = Persistence createEntityManagerFactory "TestUnit"
    var id = -1
    {
      val em = emf.createEntityManager
      val p = new Project2("Foo")
      val m = new Milestone2("Bar")
      p.milestones.add(m)
      m.project=p
      val tx = em.getTransaction()
      try {
	tx.begin()
	em persist p
	tx.commit()
	id = p.id
      } catch {
	case e =>
	  tx.rollback();
        throw e
      }
      em.close()
    }
    {
      implicit val em = emf.createEntityManager
      val p2 = Project2.find(id)
      try {
	assert("Foo" === p2.title)
	assert("Bar" === p2.milestones.get(0).title)
	assert("Foo" === p2.milestones.get(0).project.title)
      } finally {
	em.close()
      }
    }
  }


  def testJPA_3 {
    val emf = Persistence createEntityManagerFactory "TestUnit"
    var id = -1
    {
      val em = emf.createEntityManager
      val p = new Project3("Foo")
      val u = new User3("Bar")
      u.projects.add(p)
      p.users.add(u)
      val tx = em.getTransaction()
      try {
	tx.begin()
	em persist p
	tx.commit()
	id = p.proj_id
      } catch {
	case e =>
	  try { tx.rollback() } catch { case _ => }
        throw e
      }
      em.close()
    }
    {
      implicit val em = emf.createEntityManager
      val p2 = Project3.find(id)
      try {
	assert("Foo" === p2.title)
	assert("Bar" === p2.users.get(0).name)
      } finally {
	em.close()
      }
    }
  }

  def testJPA_4 {
    val emf = Persistence createEntityManagerFactory "TestUnit"
    var id = -1
    {
      val em = emf.createEntityManager
      val p = new Project4("Foo")
      val u = new User4("Bar")
      val r = new Role4("foobar")
      u.projects.add(r)
      p.users.add(r)
      r.user=u
      r.project=p
      val tx = em.getTransaction()
      try {
	tx.begin()
	em persist p
	tx.commit()
	id = p.proj_id
      } catch {
	case e =>
	  try { tx.rollback() } catch { case _ => }
        throw e
      }
      em.close()
    }
    {
      implicit val em = emf.createEntityManager
      val p2 = Project4.find(id)
      try {
	assert("Foo" === p2.title)
	assert("foobar" === p2.users.get(0).title)
	assert("Bar" === p2.users.get(0).user.name)
      } finally {
	em.close()
      }
    }
  }

}
